@@ -116,6 +116,39 @@ def generate_file_metadata(filename:str, parentFolderId:str, mimeType:str) -> di
     'parents': [parentFolderId]
   }
 
+def search_files_from_google_drive_folder_by_filename(driveService:Resource, folderId:str, fileMimeType:str=None, targetedFilename:str=None) -> list:
+  """Searching for files by mimetype and filename in specific GoogleDrive folder
+
+  Args:
+      driveService (Resource): google drive service
+      folderId (str): Google drive folder Id
+      fileMimeType (str, optional): file mime type. For example:
+        image/png or image/jpeg for images
+        application/vnd.openxmlformats-officedocument.spreadsheetml.sheet for xlsx file
+        application/vnd.ms-excel for xls file
+        text/csv for csv file
+        Defaults to None.
+      targetedFilename (str, optional): Filename to search. Defaults to None. If filename's none, get all files in the folder
+
+  Returns:
+      list: list of files dictionary. An item in the list consist of id of the file and filename
+  """
+  logger.info("Listing files in folder:", folderId)
+
+  mimeType = f"mimeType = '{fileMimeType}' and " if fileMimeType is not None else ""
+  filename = f"name = '{targetedFilename}' and " if targetedFilename is not None else ""
+
+  pageToken = None
+  results = driveService.files().list(
+    q=f"{mimeType} {filename} trashed = false",
+    spaces='drive',
+    fields='nextPageToken, files(id, name)',
+    pageToken=pageToken,
+    orderBy="createdTime desc",
+  ).execute()
+
+  return results.get('files', [])
+
 def upload_file_to_google(driveService:Resource, localFileLocation:str, filename:str, parentFolderId:str, mimeType:str) -> str:
   """Upload a file from local to google drive folder
 
@@ -187,7 +220,7 @@ def get_folder_id_from_shared_drive_by_folder_name(driveService,
     Returns:
         str: id of the Google Drive folder if found in the Shared Drive; otherwise, None.
     """
-    folders = get_folder_in_shared_drive(sharedDriveId, driveService)
+    folders = get_folder_in_shared_drive(driveService, sharedDriveId)
     if not folders:
       return None
     for each in folders:
